Traits
- CAssign
- Trait for C assign emulation in Rust
- CFunc
Float - A collection of Rust methods for emulating standard C behaviour for floating point numbers
(
f32,f64) - CFunc
Int - A collection of Rust methods for emulating standard C behaviour for integers
(e.g.
i8,u8,i16, etc.) - CFunc
Point - A collection of Rust methods for emulating standard C behaviour for pointer arrays
- CIndex
- A trait for indexing raw pointers